================================
:code:`Trakt['users/*/history']`
================================

.. automodule:: trakt.interfaces.users.history

  .. autoclass:: UsersHistoryInterface
    :members: flags, get
    :undoc-members:
